@@ -3,6 +3,7 @@ from typing import Any, Union
 from unittest import mock
 from unittest.mock import PropertyMock
 
+import pytest
 from github.GithubObject import Attribute, CompletableGithubObject, NotSet
 
 from githubapp.LazyCompletableGithubObject import LazyCompletableGithubObject
@@ -10,6 +11,19 @@ from githubapp.LazyCompletableGithubObject import LazyCompletableGithubObject
 
 class LazyClass(CompletableGithubObject):
     def __init__(self, *args, **kwargs):
+        """
+        Initialize the object.
+
+        Args:
+            *args: Variable length argument list.
+            **kwargs: Arbitrary keyword arguments.
+
+        Raises:
+            None
+
+        Example:
+            obj = ClassName()
+        """
         self._url = Attribute
         self._url.value = "url"
         super().__init__(*args, **kwargs)
@@ -37,13 +51,6 @@ def test_lazy():
 
 
 def test_lazy_requester():
-
-    # noinspection PyPep8Naming
-    class RequesterTest:
-        @staticmethod
-        def requestJsonAndCheck(*_args):
-            return {}, {"attr1": "value1"}
-
     with (
         mock.patch("githubapp.LazyCompletableGithubObject.GithubIntegration"),
         mock.patch("githubapp.LazyCompletableGithubObject.AppAuth") as app_auth,
@@ -60,9 +67,36 @@ def test_lazy_requester():
         ),
         mock.patch.dict(os.environ, {"PRIVATE_KEY": "private-key"}, clear=True),
     ):
-        instance = LazyCompletableGithubObject.get_lazy_instance(LazyClass, attributes={})
+        instance = LazyCompletableGithubObject.get_lazy_instance(
+            LazyClass, attributes={}
+        )
         assert instance._attr1.value is None
         assert instance.attr1 == "value1"
         assert instance._attr1.value == "value1"
 
     app_auth.assert_called_once_with(123, "private-key")
+
+
+def test_lazy_requester_attribute_error():
+    with (
+        mock.patch("githubapp.LazyCompletableGithubObject.GithubIntegration"),
+        mock.patch("githubapp.LazyCompletableGithubObject.AppAuth"),
+        mock.patch("githubapp.LazyCompletableGithubObject.Token"),
+        mock.patch(
+            "githubapp.LazyCompletableGithubObject.Requester._Requester__check",
+            return_value=({}, {"attr1": "value1"}),
+        ),
+        mock.patch("githubapp.LazyCompletableGithubObject.Requester.requestJson"),
+        mock.patch(
+            "githubapp.LazyCompletableGithubObject.Event.hook_installation_target_id",
+            new_callable=PropertyMock,
+            return_value=123,
+        ),
+        mock.patch.dict(os.environ, {"PRIVATE_KEY": "private-key"}, clear=True),
+    ):
+        instance = LazyCompletableGithubObject.get_lazy_instance(
+            LazyClass, attributes={}
+        )
+        with pytest.raises(AttributeError):
+            # noinspection PyStatementEffect
+            instance._requester.attr
